@@ -10,6 +10,13 @@ object and the way in which archives are managed and maintained.
 """
 
 from abc import ABCMeta, abstractmethod
+from datetime import datetime
+from typing import Optional
+
+from histore.archive.reader import ArchiveReader
+from histore.archive.schema import ArchiveSchema
+from histore.archive.snapshot import Snapshot, SnapshotListing
+from histore.archive.writer import ArchiveWriter
 
 
 class ArchiveStore(metaclass=ABCMeta):
@@ -17,10 +24,16 @@ class ArchiveStore(metaclass=ABCMeta):
     archive information.
     """
     @abstractmethod
-    def commit(self, schema, writer, snapshots):  # pragma: no cover
+    def commit(
+        self, schema: ArchiveSchema, writer: ArchiveWriter, version: int,
+        valid_time: Optional[datetime] = None,
+        description: Optional[str] = None
+    ) -> Snapshot:  # pragma: no cover
         """Commit a new version of the dataset archive. The modified components
         of the archive are given as the three arguments of this method.
 
+        Returns the handle for the newly created snapshot.
+
         Parameters
         ----------
         schema: histore.archive.schema.ArchiveSchema
@@ -28,14 +41,22 @@ class ArchiveStore(metaclass=ABCMeta):
         writer: histore.archive.writer.ArchiveWriter
             Instance of the archive writer class returned by this store that
             was used to output the rows of the new archive version.
-        snapshots: histore.archive.snapshot.SnapshotListing
-            Modified list of snapshots in the new archive. The new archive
-            version is the last entry in the list.
+        version: int
+            Unique version identifier for the new snapshot.
+        valid_time: datetime.datetime, default=None
+            Timestamp when the snapshot was first valid. A snapshot is valid
+            until the valid time of the next snapshot in the archive.
+        description: string, default=None
+            Optional user-provided description for the snapshot.
+
+        Returns
+        -------
+        histore.archive.snapshot.Snapshot
         """
         raise NotImplementedError()
 
     @abstractmethod
-    def is_empty(self):  # pragma: no cover
+    def is_empty(self) -> bool:  # pragma: no cover
         """True if the archive does not contain any snapshots yet.
 
         Returns
@@ -45,7 +66,7 @@ class ArchiveStore(metaclass=ABCMeta):
         raise NotImplementedError()
 
     @abstractmethod
-    def get_reader(self):  # pragma: no cover
+    def get_reader(self) -> ArchiveReader:  # pragma: no cover
         """Get the row reader for this archive.
 
         Returns
@@ -55,7 +76,7 @@ class ArchiveStore(metaclass=ABCMeta):
         raise NotImplementedError()
 
     @abstractmethod
-    def get_schema(self):  # pragma: no cover
+    def get_schema(self) -> ArchiveSchema:  # pragma: no cover
         """Get the schema history for the archived dataset.
 
         Returns
@@ -65,7 +86,7 @@ class ArchiveStore(metaclass=ABCMeta):
         raise NotImplementedError()
 
     @abstractmethod
-    def get_snapshots(self):  # pragma: no cover
+    def get_snapshots(self) -> SnapshotListing:  # pragma: no cover
         """Get listing of all snapshots in the archive.
 
         Returns
@@ -75,7 +96,7 @@ class ArchiveStore(metaclass=ABCMeta):
         raise NotImplementedError()
 
     @abstractmethod
-    def get_writer(self):  # pragma: no cover
+    def get_writer(self) -> ArchiveWriter:  # pragma: no cover
         """Get a writer for a new version of the archive.
 
         Returns
